import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

class UmengCrash {
  static const MethodChannel _channel =
      const MethodChannel('umeng.crash.plugin');

  ///
  /// 预初始化SDK
  /// [appKey]                友盟控制台的appKey
  /// [channel]               渠道：应用宝、小米应用商店、appstore等
  ///
  static Future<bool> preInit({
    @required String appKey,
    @required String channel,
  }) async {
    final bool result = await _channel
        .invokeMethod('preInit', {'appKey': appKey, 'channel': channel});
    return result;
  }

  ///
  /// 初始化SDK
  /// [appKey]                友盟控制台的appKey
  /// [channel]               渠道：应用宝、小米应用商店、appstore等
  /// [deviceType]            设备类型 1、手机 2、android机顶盒等
  /// [pushSecret]            推送密钥
  ///
  static Future<bool> init({
    @required String appKey,
    @required String channel,
    int deviceType = 1,
    String pushSecret,
  }) async {
    final bool result = await _channel.invokeMethod('init', {
      'appKey': appKey,
      'channel': channel,
      'deviceType': deviceType,
      'pushSecret': pushSecret ?? appKey
    });
    return result;
  }

  ///
  /// 自定义版本号 (可选),若不使用，将会自动采集
  /// [version]                   app版本号, "1.0.0"
  /// [subVersion]                发布类型, "release",
  /// [buildId]                   版本id, "0001"
  ///
  static Future<bool> setAppVersion({
    @required String version,
    @required String subVersion,
    @required String buildId,
  }) async {
    final bool result = await _channel.invokeMethod('setAppVersion', {
      'version': version,
      'subVersion': subVersion,
      'buildId': buildId,
    });
    return result;
  }

  ///
  /// 自定义异常上报接口
  /// [e]                 异常信息
  /// [type]              异常类型
  ///
  static Future<bool> generateCustomLog({
    @required String e,
    @required String type,
  }) async {
    final bool result = await _channel.invokeMethod('generateCustomLog', {
      'e': e,
      'type': type,
    });
    return result;
  }

  ///
  /// 程序退出时，用于保存统计数据的API。
  /// 如果开发者调用kill或者exit之类的方法杀死进程，或者双击back键会杀死进程，请务必在此之前调用onKillProcess方法，用来保存统计数据。
  ///
  static Future<bool> onKillProcess() async {
    final bool result = await _channel.invokeMethod('onKillProcess');
    return result;
  }

  ///
  /// 可选
  ///
  static Future<String> get getOaid async {
    final String version = await _channel.invokeMethod('getOaid');
    return version;
  }

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}
